@@ -14,9 +14,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
+import os
 from argeasy import ArgEasy
 
-from . import exceptions
+from . import exceptions, ignore
 from .__init__ import __version__
 from .pie import Pie
 
@@ -39,8 +40,10 @@ def main() -> int:
 
     # commit and file tracking
     parser.add_flag('-m', 'Adds a message to the commit')
-    # parser.add_flag('-a', 'Selects all tracked files', action='store_true')
-    # parser.add_flag('-A', 'Selects all files in the directory', action='store_true')
+    parser.add_flag('-am', 'Select all tracked files and set a commit message')
+
+    parser.add_flag('-a', 'Selects all tracked files to commit', action='store_true')
+    parser.add_flag('-A', 'Selects all files in the directory to track', action='store_true')
 
     # config
     parser.add_flag('--author', 'Repository author')
@@ -113,18 +116,46 @@ def main() -> int:
                     print(f'Date: {info["datetime"]}')
                     print(f'Changed files: {len(info["files"])}\n')
                     print(f'    {info["message"]}\n')
-            elif args.add:
-                files = args.add
+            elif args.add is not None:
+                files_to_add = args.add
+                all_files_flag = args.A
 
-                for file in files:
+                tracked_info = pie.get_tracked_files()
+                tracked_files = tracked_info.keys()
+
+                if all_files_flag:
+                    not_ignored_files = ignore.get_not_ignored_files()
+                    for file in not_ignored_files:
+                        file = os.path.join('.', file)
+                        if file not in tracked_files:
+                            files_to_add.append(file)
+
+                if not files_to_add:
+                    print('\033[31merror: no file specified to track (use "pie add" argument and '
+                          'pass a list of files or use the "-A" flag to select all files)\033[m')
+                    return 1
+
+                for file in files_to_add:
                     try:
                         pie.track_file(file)
                     except FileNotFoundError:
                         print(f'\033[31merror: file "{file}" not found')
                         return 1
-            elif args.commit:
+            elif args.commit is not None:
                 files = args.commit
                 message = args.m
+                all_tracked_files_flag = args.a
+
+                if args.am:
+                    message = args.am
+                    all_tracked_files_flag = True
+
+                if all_tracked_files_flag:
+                    tracked_info = pie.get_tracked_files()
+
+                    for filepath in tracked_info.keys():
+                        if pie.file_has_changed(filepath):
+                            files.append(filepath)
 
                 if not message:
                     print('\033[33ma message to describe your commit is required.\033[m')
@@ -136,6 +167,10 @@ def main() -> int:
                 except exceptions.NoFilesToCommitError:
                     print('no changed files, commit cancelled')
                     return 1
+                except exceptions.FileNotTrackedError as err:
+                    print(f'\033[31m{err.args[0]}\033[m')
+                    print('(use "pie add" argument to add files)')
+                    return 1
 
                 print(f'\033[1m\033[4;33m[{commit_hash[:8]}]\033[m {commit["message"]}')
                 print(f'  {len(commit["files"])} files were modified')
