@@ -23,3 +23,18 @@ class RepositoryExistsError(Exception):
 class CommitIntegrityError(Exception):
     def __init__(self, *args):
         super().__init__(*args)
+
+
+class FileNotTrackedError(Exception):
+    def __init__(self, *args):
+        super().__init__(*args)
+
+
+class NoFilesToCommitError(Exception):
+    def __init__(self, *args):
+        super().__init__(*args)
+
+
+class RepositoryNotExistsError(Exception):
+    def __init__(self, *args):
+        super().__init__(*args)
