@@ -170,15 +170,16 @@ class Pie(object):
         if './' not in filepath:
             filepath = os.path.join('.', filepath)
 
-        file_info = {
-            'filename': filepath,
-            'commits': []
-        }
-
         pieces_refs = self._get_pieces_refs()
-        pieces_refs['tracked'][filepath] = file_info
 
-        self._write_pieces_refs(pieces_refs)
+        if filepath not in pieces_refs['tracked']:
+            file_info = {
+                'filename': filepath,
+                'commits': []
+            }
+
+            pieces_refs['tracked'][filepath] = file_info
+            self._write_pieces_refs(pieces_refs)
 
     def index_file_lines(self, filepath: str) -> dict:
         """Numbers the lines of the file in a dictionary
@@ -401,7 +402,7 @@ class Pie(object):
         pieces_refs = self._get_pieces_refs()
         return pieces_refs['commits']
 
-    def _file_has_changed(self, filepath: str) -> bool:
+    def file_has_changed(self, filepath: str) -> bool:
         previous_file_lines = self.join_file_changes(filepath)
         current_file_lines = self.index_file_lines(filepath)
 
@@ -432,7 +433,7 @@ class Pie(object):
                     'status': 'new'
                 })
             else:
-                file_has_changed = self._file_has_changed(filepath)
+                file_has_changed = self.file_has_changed(filepath)
                 
                 if file_has_changed:
                     files_status.append({
@@ -480,7 +481,7 @@ class Pie(object):
                         'diff': self.index_file_lines(filepath),
                         'previous_hash': 0
                     }
-                else:
+                elif self.file_has_changed(filepath):
                     previous_hash = self._get_last_piece_hash(filepath)
                     lines_difference = self.get_file_difference(filepath)
 
